<?php

namespace App\Admin;

use Sonata\AdminBundle\Admin\AbstractAdmin;
use Sonata\AdminBundle\Datagrid\ListMapper;
use Sonata\AdminBundle\Form\FormMapper;
use Sonata\AdminBundle\Datagrid\DatagridMapper;
use Sonata\AdminBundle\Datagrid\ProxyQueryInterface;
use Sonata\AdminBundle\Show\ShowMapper;
use Symfony\Component\Form\Extension\Core\Type\DateTimeType;
use Symfony\Component\Form\Extension\Core\Type\TextareaType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Sonata\Form\Type\DateTimePickerType;

class EventosAdmin extends AbstractAdmin
{

    protected function configureQuery(ProxyQueryInterface $query): ProxyQueryInterface
    {

        $query->orderBy($query->getRootAlias() . '.id', 'DESC');

        return $query;
    }

    protected function configureFormFields(FormMapper $formMapper): void
    {
        $formMapper
            ->add('titulo')
            ->add('descripcion')
            ->add('fechaInicio', DateTimePickerType::class, [
                'label' => 'Fecha Inicio',
                'help' => 'dd/mm/aaaa HH:mm',
                'format' => 'dd/MM/yyyy HH:mm',
            ])
            ->add('fechaFin', DateTimePickerType::class, [
                'label' => 'Fecha Fin',
                'help' => 'dd/mm/aaaa HH:mm',
                'format' => 'dd/MM/yyyy HH:mm',
            ])
            ->add('ubicacion', null, [
                'attr' => ['class' => 'ubicacion'],
                'required' => false
            ])
        ;
    }

    protected function configureDatagridFilters(DatagridMapper $datagridMapper): void
    {
        $datagridMapper
            ->add('titulo')
            ->add('fechaInicio')
            ->add('fechaFin');
    }

    protected function configureListFields(ListMapper $listMapper): void
    {
        $listMapper
            ->addIdentifier('id')
            ->add('titulo')
            ->add('fechaInicio')
            ->add('fechaFin')
            ->add('_action', 'actions', [
                'actions' => [
                    'show' => [],
                    'edit' => [],
                ],
                'label' => 'Acciones',
            ])
        ;
    }
    protected function configureShowFields(ShowMapper $show): void
    {
        $show
            ->add('titulo')
            ->add('descripcion')
            ->add('fechaInicio', null, [
                'label' => 'Fecha Inicio',
            ])
            ->add('fechaFin', null, [
                'label' => 'Fecha Fin',
            ])
            ->add('ubicacion', null, [
                'template' => 'admin/mapa_evento.html.twig'
            ])
        ;
    }
}