<?php

namespace App\Admin;

use Sonata\AdminBundle\Admin\AbstractAdmin;
use Sonata\AdminBundle\Datagrid\DatagridMapper;
use Sonata\AdminBundle\Datagrid\ListMapper;
use Sonata\AdminBundle\Form\FormMapper;
use Sonata\AdminBundle\Show\ShowMapper;
use Sonata\AdminBundle\Form\Type\ModelType;
use Sonata\UserBundle\Model\UserManagerInterface;
use Symfony\Component\Form\Extension\Core\Type\PasswordType;
use Sonata\UserBundle\Form\Type\RolesMatrixType;
use Sonata\UserBundle\Admin\Model\UserAdmin as BaseUserAdmin;

class UserAdmin extends BaseUserAdmin
{

    public function __construct(UserManagerInterface $userManager)
    {
        parent::__construct($userManager);
    }

    protected function configureFormFields(FormMapper $formMapper): void
    {

        $formMapper
            ->with('general', ['class' => 'col-md-4'])
                ->add('username')
                ->add('email')
                ->add('plainPassword', PasswordType::class, [
                    'required' => (!$this->hasSubject() || null === $this->getSubject()->getId()),
                ])
                ->add('fabricante', ModelType::class, [
                    'class' => 'App\Entity\Fabricantes',
                    'property' => 'nombre',
                    'required' => false,
                    'btn_add' => false,
                    'label' => 'Fabricante',
                ])
                ->add('cliente', ModelType::class, [
                    'class' => 'App\Entity\Clientes',
                    'property' => 'nombre',
                    'required' => false,
                    'btn_add' => false,
                    'label' => 'Cliente',
                ])
                ->add('enabled')
            ->end()
            ->with('roles', ['class' => 'col-md-8'])
                ->add('realRoles', RolesMatrixType::class, [
                    'label' => false,
                    'multiple' => true,
                    'required' => false,
                ])
            ->end()
        ;
        
    }

    protected function configureListFields(ListMapper $list): void
    {
        $list
            ->addIdentifier('username')
            ->add('email')
            ->add('enabled', null, ['editable' => true])
            ->add('createdAt')
            ->add('_action', 'actions', [
                'actions' => [
                    'show' => [],
                    'edit' => [],
                ],
                'label' => 'Acciones',
            ]);

        #if ($this->isGranted('ROLE_ALLOWED_TO_SWITCH')) {
            #$list
                #->add('impersonating', FieldDescriptionInterface::TYPE_STRING, [
                    #'virtual_field' => true,
                    #'template' => '@SonataUser/Admin/Field/impersonating.html.twig',
                #]);
        #}
    }

    protected function configureDatagridFilters(DatagridMapper $filter): void
    {
        $filter
            ->add('id')
            ->add('username')
            ->add('email');
    }

    protected function configureShowFields(ShowMapper $show): void
    {
        $show
            ->add('username')
            ->add('email');
    }

}