<?php

namespace App\Entity;

use App\Repository\FabricantesRepository;
use Doctrine\ORM\Mapping as ORM;
use Doctrine\Common\Collections\ArrayCollection;

/**
 * @ORM\Entity(repositoryClass=FabricantesRepository::class)
 */
class Fabricantes
{
    /**
     * @ORM\Id
     * @ORM\GeneratedValue
     * @ORM\Column(type="integer")
     */
    private $id;

    /**
     * @ORM\Column(type="string", length=255)
     */
    private $nombre;

    /**
     * @ORM\Column(type="string", length=255, nullable=true)
     */
    private $direccion;

    /**
     * @ORM\Column(type="string", length=255, nullable=true)
     */
    private $telefono;

    /**
     * @ORM\Column(type="string", length=255, nullable=true)
     */
    private $email;

    /**
     * @ORM\OneToMany(targetEntity="App\Entity\User", mappedBy="fabricante", cascade={"persist", "remove"})
     */
    private $usuarios;

    /**
     * @ORM\OneToMany(targetEntity="App\Entity\Catalogos", mappedBy="fabricante", cascade={"persist", "remove"})
     */
    private $catalogos;

    /**
     * @ORM\OneToMany(targetEntity="App\Entity\Pedidos", mappedBy="fabricante", cascade={"persist", "remove"})
     */
    private $pedidos;

    /**
     * @ORM\Column(type="boolean")
     */
    private $activo;

    public function __construct()
    {
        $this->usuarios = new ArrayCollection();
        $this->catalogos = new ArrayCollection();
        $this->pedidos = new ArrayCollection();
    }

    public function getId(): ?int
    {
        return $this->id;
    }

    public function getNombre(): ?string
    {
        return $this->nombre;
    }

    public function setNombre(string $nombre): self
    {
        $this->nombre = $nombre;

        return $this;
    }

    public function getDireccion(): ?string
    {
        return $this->direccion;
    }

    public function setDireccion(?string $direccion): self
    {
        $this->direccion = $direccion;

        return $this;
    }

    public function getTelefono(): ?string
    {
        return $this->telefono;
    }

    public function setTelefono(?string $telefono): self
    {
        $this->telefono = $telefono;

        return $this;
    }

    public function getEmail(): ?string
    {
        return $this->email;
    }

    public function setEmail(?string $email): self
    {
        $this->email = $email;

        return $this;
    }

    public function getUsuarios()
    {
        return $this->usuarios;
    }

    public function addUsuario(User $usuario): self
    {
        if (!$this->usuarios->contains($usuario)) {
            $this->usuarios[] = $usuario;
            $usuario->setFabricante($this);
        }

        return $this;
    }

    public function removeUsuario(User $usuario): self
    {
        if ($this->usuarios->removeElement($usuario)) {
            // set the owning side to null (unless already changed)
            if ($usuario->getFabricante() === $this) {
                $usuario->setFabricante(null);
            }
        }

        return $this;
    }

    public function getCatalogos()
    {
        return $this->catalogos;
    }

    public function addCatalogo(Catalogos $catalogo): self
    {
        if (!$this->catalogos->contains($catalogo)) {
            $this->catalogos[] = $catalogo;
            $catalogo->setFabricante($this);
        }

        return $this;
    }

    public function removeCatalogo(Catalogos $catalogo): self
    {
        if ($this->catalogos->removeElement($catalogo)) {
            if ($catalogo->getFabricante() === $this) {
                $catalogo->setFabricante(null);
            }
        }

        return $this;
    }

    public function getPedidos()
    {
        return $this->pedidos;
    }

    public function addPedido(Pedidos $pedido): self
    {
        if (!$this->pedidos->contains($pedido)) {
            $this->pedidos[] = $pedido;
            $pedido->setFabricante($this);
        }

        return $this;
    }

    public function removePedido(Pedidos $pedido): self
    {
        if ($this->pedidos->removeElement($pedido)) {
            // set the owning side to null (unless already changed)
            if ($pedido->getFabricante() === $this) {
                $pedido->setFabricante(null);
            }
        }

        return $this;
    }

    public function getActivo()
    {
        return $this->activo;
    }

    public function setActivo($activo): self
    {
        $this->activo = $activo;

        return $this;
    }
}
